**Figures for Binder, Janson, and Verbrugge
set scheme s1color


**Figure 1: Long-run PCE  forecasts for the 11 SPF respondents who made at least 50 forecasts from 2007Q1 to 2022Q1
use spf_inflation.dta, clear
egen count=count(pce_forward), by(ID)
egen id=group(ID) if count>=50 & count!=.
gen t=yq(YEAR, QUARTER)
format t %tq
drop if id==.
xtset id t
scatter pce_forward id if YEAR<=2011, xlabel(1(1)11) yline(2) yline(2.5, lpattern(.)) yline(1.5, lpattern(.)) yline(2.2, lpattern(-)) yline(1.8, lpattern(-)) xtitle("Forecaster") subtitle("2007-2011") msymbol(Oh) msize(vsmall) ylabel(1(1)5)
graph save g1.gph, replace
scatter pce_forward id if YEAR>=2012&YEAR<=2016, xlabel(1(1)11) yline(2) yline(2.5, lpattern(.)) yline(1.5, lpattern(.)) yline(2.2, lpattern(-)) yline(1.8, lpattern(-))xtitle("Forecaster") subtitle("2012-2016") msymbol(Oh) msize(vsmall) ylabel(1(1)5)
graph save g2.gph, replace
scatter pce_forward id if YEAR>=2017&YEAR<=2022, xlabel(1(1)11) yline(2) yline(2.5, lpattern(.)) yline(1.5, lpattern(.)) yline(2.2, lpattern(-)) yline(1.8, lpattern(-)) xtitle("Forecaster") subtitle("2017-2022Q1") msymbol(Oh) msize(vsmall) ylabel(1(1)5)
graph save g3.gph, replace
graph combine g1.gph g2.gph g3.gph, cols(1)
graph display, ysize(20) xsize(18)
graph export Figdots.png, replace

**Figure 2: Examples of long-run PCE forecasts for two SPF respondents
xtline pce_forward if id==6|id==7, overlay plot1opts(lpattern(dash)) tlabel(, format(%tqCCYY)) xtitle("") legend(label(1 "Forecaster 6 (ID 518)") label(2 "Forecaster 7 (ID 535)")) tline(208) tline(228) ytitle("Expected inflation")
graph export FigIndividualTimeseries.png, replace

**Figure 3: Bounds anchoring over time
use boundsanchoringdatatimeseries.dta, clear
twoway tsline boundanchored05 boundanchored02, lpattern(dash solid) xtitle("") tlabel(192(12)244, format(%tqCCYY)) ytitle("Share of forecasters") subtitle("A. Bounds Anchoring") legend(label(1 "0.5 bounds anchored") label(2 "0.2 bounds anchored") cols(1) ring(0) bplacement(nwest))
graph save g1.gph, replace
twoway tsline p75RMSD p50RMSD p25RMSD, lpattern(-. solid dash) xtitle("") tlabel(192(12)244, format(%tqCCYY)) ytitle("RMSD") subtitle("B. RMSD") legend(label(1 "75th pctl") label(2 "50th pctl") label(3 "25th pctl") cols(1) ring(0) bplacement(neast))
graph save g2.gph, replace
graph combine g1.gph g2.gph, cols(1)
graph display, ysize(13) xsize(10)
graph export FigBoundAnchored.png, replace


**Figure 4: Bounds anchoring measures using 5yr and 10yr instead of 5yr/5yr forward
use boundsanchoringdatatimeseries.dta, clear
twoway tsline boundanchored05 boundanchored055y boundanchored0510y, lpattern(solid dash -.) xtitle("") tlabel(192(12)244, format(%tqCCYY)) ytitle("Share of forecasters") subtitle("A. 0.5-Bounds Anchoring")
graph save g2.gph, replace
twoway tsline p50RMSD p50RMSD5y p50RMSD10y, lpattern(solid dash -.) xtitle("") tlabel(192(12)244, format(%tqCCYY)) ytitle("Median RMSD") legend(label(1 "5y/5y forward") label(2 "5y") label(3 "10y") cols(3) ring(0) bplacement(neast) symxsize(*0.6)) subtitle("B. Median RMSD")
graph save g3.gph, replace
grc1leg g2.gph g3.gph, cols(1) legendfrom(g3.gph)
graph display, ysize(20) xsize(17)
graph export Fig10y.png, replace

**Figure 5: Comparison of RMSD from PCE and CPI forecasts
use boundsanchoringdatatimeseries.dta, clear
twoway tsline p50RMSD p50RMSDcpi, lpattern(dash solid -.) xtitle("") tlabel(192(12)244, format(%tqCCYY)) ytitle("Median RMSD") legend(label(1 "PCE") label(2 "CPI") cols(1) ring(0) bplacement(neast))
graph export FigRMSDcpi.png, replace


**Figure 6: Examples of "box anchoring" for two SPF respondents
use boundsanchoringdata.dta, clear
replace id=.
replace id=6 if ID==518
replace id=7 if ID==535
gen ymax=2.8
gen ymin=1.8
gen xvalue=2

twoway (bar ymax xvalue if id==6, base(1.8) color(gray%30))( scatter cpi_forward pce_forward if (id==6 & YEAR<=2011), jitter(5) xlabel(0(0.5)3) ylabel(0(0.5)3) ytitle("CPI") xtitle("PCE")), legend (off) subtitle("Forecaster 6, 2007-2011")
graph save g1.gph, replace

twoway (bar ymax xvalue if id==6, base(1.8) color(gray%30))( scatter cpi_forward pce_forward if (id==6 & YEAR>=2012 & YEAR<=2016), jitter(5) xlabel(0(0.5)3) ylabel(0(0.5)3) ytitle("CPI") xtitle("PCE")), legend (off) subtitle("Forecaster 6, 2012-2016") 
graph save g2.gph, replace

twoway (bar ymax xvalue if id==7, base(1.8) color(gray%30))( scatter cpi_forward pce_forward if (id==7 & YEAR>=2017), jitter(5) xlabel(0(0.5)3) ylabel(0(0.5)3) ytitle("CPI") xtitle("PCE")), legend (off) subtitle("Forecaster 6, 2017-2022Q1") 
graph save g3.gph, replace

twoway (bar ymax xvalue if id==7, base(1.8) color(gray%30))( scatter cpi_forward pce_forward if (id==7 & YEAR<=2011), jitter(5) xlabel(0(0.5)3) ylabel(0(0.5)3) ytitle("CPI") xtitle("PCE")), legend (off) subtitle("Forecaster 7, 2007-2011")
graph save g4.gph, replace

twoway (bar ymax xvalue if id==7, base(1.8) color(gray%30))( scatter cpi_forward pce_forward if (id==7 & YEAR>=2012 & YEAR<=2016), jitter(5) xlabel(0(0.5)3) ylabel(0(0.5)3) ytitle("CPI") xtitle("PCE")), legend (off) subtitle("Forecaster 7, 2012-2016") 
graph save g5.gph, replace

twoway (bar ymax xvalue if id==6, base(1.8) color(gray%30))( scatter cpi_forward pce_forward if (id==6 & YEAR>=2017), jitter(5) xlabel(0(0.5)3) ylabel(0(0.5)3) ytitle("CPI") xtitle("PCE")), legend (off) subtitle("Forecaster 7, 2017-2022Q1") 
graph save g6.gph, replace

graph combine g1.gph g2.gph g3.gph g4.gph g5.gph g6.gph, cols(3)
graph export Figboxes.png, replace


**Figure 7: Box anchored expectations
use boundsanchoringdatatimeseries.dta, clear
twoway tsline boxanchored02 boxanchored05, lpattern(solid dash) xtitle("") tlabel(192(12)244, format(%tqCCYY)) ytitle("Share of forecasters") legend(label(1 "(0.2, 0.2)-box anchored") label(2 "(0.5, 0.5)-box anchored") order(2 1) cols(1) ring(0) bplacement(nwest))
graph export FigBoxAnchored.png, replace

**Figure 8: Changing time trends in bounds anchoring measures
**See file Regressions.do


**Appendix Figure A1: Time series plots of long-run PCE forecasts for respondents who made at least 50 forecasts
use spf_inflation.dta, clear
egen count=count(pce_forward), by(ID)
egen id=group(ID) if count>=50 & count!=.
gen t=yq(YEAR, QUARTER)
format t %tq
drop if id==.
xtset id t
forvalues j=1/11 {
    tsline pce_forward if id==`j', tlabel(192(12)244, format(%tqCCYY)) subtitle("Forecaster `j'") xtitle("") ytitle("Expected inflation") ylabel(0(1)5)
	graph save g`j'.gph, replace
}
graph combine g1.gph g2.gph g3.gph g4.gph g5.gph g6.gph g7.gph g8.gph g9.gph g10.gph g11.gph, cols(3)
graph display, ysize(20) xsize(18)
graph export FigIndividualTimeseriesAll.png, replace



*Appendix Figure A2: Individual forecasters' RMSD plots
use boundsanchoringdata.dta, clear
replace count=. if count<50
drop id
egen id=group(ID) if count!=.
forvalues j=1/11 {
    tsline RMSD if id==`j', tlabel(192(12)244, format(%tqCCYY)) subtitle("Forecaster `j'") xtitle("") ytitle("RMSD") ylabel(0(0.3)1.5)
	graph save g`j'.gph, replace
}
graph combine g1.gph g2.gph g3.gph g4.gph g5.gph g6.gph g7.gph g8.gph g9.gph g10.gph g11.gph, cols(3)
graph display, ysize(20) xsize(18)
graph export FigIndividualRMSD.png, replace

**Appendix Figure A4: Alternative window lengths
use boundsanchoringdatatimeseries.dta, clear
twoway tsline boundanchored02w5 boundanchored02 boundanchored02w13, lpattern(dash solid -.) xtitle("") tlabel(192(12)244, format(%tqCCYY)) ytitle("Share of forecasters") legend(label(1 "5Q") label(2 "9Q") label(3 "13Q") cols(3) ring(0) bplacement(nwest)) subtitle("A. 0.2-Bounds Anchoring")
graph save g1.gph, replace
twoway tsline boundanchored05w5 boundanchored05 boundanchored05w13, lpattern(dash solid -.) xtitle("") tlabel(192(12)244, format(%tqCCYY)) ytitle("Share of forecasters") legend(label(1 "5Q window") label(2 "9Q window") label(3 "13Q window") cols(3) ring(0) bplacement(nwest)) subtitle("B. 0.5-Bounds Anchoring")
graph save g2.gph, replace
twoway tsline p50RMSDw5 p50RMSD p50RMSDw13, lpattern(dash solid -.) xtitle("") tlabel(192(12)244, format(%tqCCYY)) ytitle("RMSD") legend(label(1 "5Q window") label(2 "9Q window") label(3 "13Q window") cols(3) ring(0) bplacement(nwest)) subtitle("C. Median RMSD")
graph save g3.gph, replace
grc1leg g1.gph g2.gph g3.gph, legendfrom(g1.gph) cols(1)
graph display, xsize(17) ysize(20)
graph export FigWindows.png, replace


**Appendix Figure A5: Alternative sample restrictions
use boundsanchoringdatatimeseries.dta, clear
twoway tsline boundanchored05small boundanchored05 boundanchored05large, lpattern(dash solid -.) ytitle("Median RMSD") xtitle("") tlabel(192(12)244, format(%tqCCYY)) legend(label(1 "Smaller") label(2 "Baseline") label(3 "Larger") cols(3)) subtitle("A. 0.5-Bounds Anchoring")
graph save g1.gph, replace
twoway tsline p50RMSDsmall p50RMSD p50RMSDlarge, lpattern(dash solid -.) ytitle("Median RMSD") xtitle("") tlabel(192(12)244, format(%tqCCYY)) legend(label(1 "Smaller") label(2 "Baseline") label(3 "Larger")) subtitle("B. Median RMSD")
graph save g2.gph, replace
grc1leg g1.gph g2.gph, legendfrom(g1.gph) cols(1)
graph display, xsize(19) ysize(20)
graph export FigAltSamples.png, replace


**Appendix Figure A6: By industry
use boundsanchoringdatatimeseries.dta, clear
twoway tsline boundanchored02_fin boundanchored02_nonfin, lpattern(solid dash) xtitle("") tlabel(192(12)244, format(%tqCCYY)) ytitle("Share of forecasters") subtitle("A. 0.2-Bounds Anchoring")
graph save g1.gph, replace
twoway tsline boundanchored05_fin boundanchored05_nonfin, lpattern(solid dash) xtitle("") tlabel(192(12)244, format(%tqCCYY)) ytitle("Share of forecasters") subtitle("B. 0.5-Bounds Anchoring")
graph save g2.gph, replace
twoway tsline p50RMSD_fin p50RMSD_nonfin, lpattern(solid dash) xtitle("") tlabel(192(12)244, format(%tqCCYY)) ytitle("Median RMSD") legend(label(1 "Finance") label(2 "Nonfinance") cols(2) ring(0) bplacement(neast)) subtitle("C. Median RMSD")
graph save g3.gph, replace
grc1leg g1.gph g2.gph g3.gph, cols(1) legendfrom(g3.gph)
graph display, ysize(20) xsize(17)
graph export FigIndustry.png, replace



**Appendix Figure A7: Forecasts and RMSD from TIPS and UCSV model
use boundsanchoringdatatimeseries.dta, clear
twoway tsline tips ucsv, tlabel(192(12)244, format(%tqCCYY)) legend(label(1 "TIPS") label(2 "UCSV") ring(0) bplacement(neast) cols(1)) ytitle("PCE inflation forecast") subtitle("A. TIPS Breakeven and UCSVSW Long-Run PCE Inflation") lpattern(solid dash) xtitle("")
graph save g1.gph, replace

twoway tsline RMSDtips RMSDucsv p50RMSD, tlabel(192(12)244, format(%tqCCYY)) legend(cols(1) label(1 "TIPS") label(2 "UCSV") label(3 "SPF") ring(0) bplacement(neast)) ytitle("RMSD") lpattern(solid dash dot) subtitle("B. RMSD from Target") xtitle("")
graph save g2.gph, replace

graph combine g1.gph g2.gph, cols(1)
graph display, ysize(20) xsize(15)
graph export FigTips.png, replace

**Drop .gph files
forvalues j=1/11 {
	erase g`j'.gph
}
