clear
set more off

********************************************
***** Pull SPF Data from Philadelphia Fed website*****
********************************************

***** Pull Long Term Inflation Data ******
*** Pull 10 YR CPI Data ***
import excel "https://www.philadelphiafed.org/-/media/frbp/assets/surveys-and-data/survey-of-professional-forecasters/historical-data/spfmicrodata.xlsx", firstrow sheet("CPI10")
save "long_term_inflation", replace
clear

*** Pull 5 YR CPI Data ***
import excel "https://www.philadelphiafed.org/-/media/frbp/assets/surveys-and-data/survey-of-professional-forecasters/historical-data/spfmicrodata.xlsx", firstrow sheet("CPI5YR")
merge 1:1 YEAR QUARTER ID using "long_term_inflation", keep(matched)
drop _merge
save "long_term_inflation", replace
clear

*** Pull 10 YR PCE Data ***
import excel "https://www.philadelphiafed.org/-/media/frbp/assets/surveys-and-data/survey-of-professional-forecasters/historical-data/spfmicrodata.xlsx", firstrow sheet("PCE10")
merge 1:1 YEAR QUARTER ID using "long_term_inflation", keep(matched)
drop _merge
save "long_term_inflation", replace
clear

*** Pull 5 YR PCE Data ***
import excel "https://www.philadelphiafed.org/-/media/frbp/assets/surveys-and-data/survey-of-professional-forecasters/historical-data/spfmicrodata.xlsx", firstrow sheet("PCE5YR")
merge 1:1 YEAR QUARTER ID using "long_term_inflation", keep(matched)
drop _merge
save "long_term_inflation", replace
save "long_term_inflation.xlsx", replace
clear


***** Pull Quarterly CPI/PCE Data *****
*** Core CPI ***
import excel "https://www.philadelphiafed.org/-/media/frbp/assets/surveys-and-data/survey-of-professional-forecasters/historical-data/spfmicrodata.xlsx", firstrow sheet("CORECPI")
drop CORECPIA CORECPIB CORECPIC
save "quarterly_inflation", replace
clear

*** Headline CPI ***
import excel "https://www.philadelphiafed.org/-/media/frbp/assets/surveys-and-data/survey-of-professional-forecasters/historical-data/spfmicrodata.xlsx", firstrow sheet("CPI")
merge 1:1 YEAR QUARTER ID using "quarterly_inflation", keep(matched)
drop CPIA CPIB CPIC _merge
save "quarterly_inflation", replace
clear

*** Core PCE ***
import excel "https://www.philadelphiafed.org/-/media/frbp/assets/surveys-and-data/survey-of-professional-forecasters/historical-data/spfmicrodata.xlsx", firstrow sheet("COREPCE")
merge 1:1 YEAR QUARTER ID using "quarterly_inflation", keep(matched)
drop COREPCEA COREPCEB COREPCEC _merge
save "quarterly_inflation", replace
clear

*** Headline PCE ***
import excel "https://www.philadelphiafed.org/-/media/frbp/assets/surveys-and-data/survey-of-professional-forecasters/historical-data/spfmicrodata.xlsx", firstrow sheet("PCE")
merge 1:1 YEAR QUARTER ID using "quarterly_inflation", keep(matched)
drop PCEA PCEB PCEC _merge
save "quarterly_inflation", replace
save "quarterly_inflation.xlsx", replace
clear


*** Merge Inflation Data ***
use "long_term_inflation", clear
merge 1:1 YEAR QUARTER ID using "quarterly_inflation", keep(matched)
drop _merge

*** Replace NAs to Missing Observations, transform variables to numeric ***
foreach x of varlist INDUSTRY PCE* CPI* CORE* {
replace `x'="." if `x'=="#N/A"
}
destring PCE* CPI* CORE* INDUSTRY, force replace

***Create 5yr/5yr Forward***
rename PCE10 PCE10YR
rename CPI10 CPI10YR
gen cpi_forward=100*(((1+CPI10YR/100)^2/(1+CPI5YR/100))-1)
gen pce_forward=100*(((1+PCE10YR/100)^2/(1+PCE5YR/100))-1)

**********Differential Variables************
***5yr/5yr Differential***
gen diff_5yr5yr=cpi_forward-pce_forward
***10yr Differential***
gen diff_10yr=CPI10YR-PCE10YR
***5yr Differential***
gen diff_5yr=CPI5YR-PCE5YR

***Drop if before 2007***
drop if YEAR<2007

***** Save as DTA *****
save "spf_inflation", replace




