clear
set more off
set scheme s1color

**FRED time series data https://fred.stlouisfed.org/graph/?g=OhEs
import excel freddata.xls, cellrange(A15:F882) firstrow clear
gen YEAR=year(obs)
gen QUARTER=quarter(obs)
collapse PCE UNRATE USR FEDFUNDS EPUMONET, by(YEAR QUARTER)
gen t=yq(YEAR, QUARTER)
format t %tq
tsset t
gen PiPCE=(PCE-l.PCE)/l.PCE*400
drop if YEAR<2007
save freddata.dta, replace
**Rolling mean and std dev of inflation in a 9-quarter window
rolling meanPCE=r(mean) sdPCE=r(sd), window(9) saving(pce.dta, replace): sum PiPCE
**Rolling mean and max of monetary policy uncertainty in a 9-quarter window
*rolling meanMPU=r(mean) maxMPU=r(max), window(9) saving(mpu.dta, replace): sum EPUMONET
use pce.dta, clear
*merge 1:1 start using mpu.dta
*drop _merge
gen t=(start+end)/2
drop start end
merge 1:1 t using freddata.dta
drop _merge
save freddata.dta, replace


**UCSVSW data
import excel tempy_Real_time_estimates_UCSVSW.xlsx, cellrange(B2:D60) firstrow clear
gen YEAR=floor(Forecast_Origin)
gen QUARTER=(Forecast_Origin-YEAR)*10
gen t=yq(YEAR, QUARTER)
tsset t
rename HeadlinePCE ucsv
save UCSVSW.dta, replace
gen sqdeviation=(ucsv-2)^2
gen boundeps02=abs(ucsv-2)<0.2
gen boundeps05=abs(ucsv-2)<0.5
rolling BOUND02=r(mean), window(9) saving(bound02.dta, replace): sum boundeps02
rolling BOUND05=r(mean), window(9) saving(bound05.dta, replace): sum boundeps05
rolling MSD=r(mean), window(9) saving(sqdev.dta, replace): sum sqdeviation
use bound05.dta, clear
foreach stub in sqdev bound02  {
	merge 1:1 start using `stub'.dta
	drop _merge
}
gen t=(start+end)/2
merge 1:1 t using UCSVSW.dta
drop _merge
gen boundanchored02ucsv=BOUND02==1 if BOUND02!=.
gen boundanchored05ucsv=BOUND05==1 if BOUND05!=.
gen RMSDucsv=MSD^(1/2)
keep ucsv RMSDucsv t boundanchored*
save UCSVSW.dta, replace

**TIPS breakeven data
import excel tips_breakeven.xlsx, sheet("monthly") cellrange(B6:C188) clear
gen YEAR=year(B)
gen MONTH=month(B)
gen QUARTER=quarter(B)
keep if MONTH==2|MONTH==5|MONTH==8|MONTH==11
gen tips=C-0.3
drop MONTH
gen t=yq(YEAR, QUARTER)
tsset t
format t %tq
save tips.dta, replace


gen sqdeviation=(tips-2)^2
gen boundeps02=abs(tips-2)<0.2
gen boundeps05=abs(tips-2)<0.5
rolling BOUND02=r(mean), window(9) saving(bound02.dta, replace): sum boundeps02
rolling BOUND05=r(mean), window(9) saving(bound05.dta, replace): sum boundeps05
rolling MSD=r(mean), window(9) saving(sqdev.dta, replace): sum sqdeviation
use bound05.dta, clear
foreach stub in sqdev bound02  {
	merge 1:1 start using `stub'.dta
	drop _merge
}
gen t=(start+end)/2
merge 1:1 t using tips.dta
drop _merge
gen boundanchored02tips=BOUND02==1 if BOUND02!=.
gen boundanchored05tips=BOUND05==1 if BOUND05!=.
gen RMSDtips=MSD^(1/2)
keep tips RMSDtips t boundanchored*
save tips.dta, replace

*SPF data but using smaller and larger samples of forecasters
run prepare_data_bounds_anchoring_altsamples.do

*SPF special questions from 2012
import excel survq212_special-questions.xls, sheet("Responses") firstrow clear
rename ForecasterID ID 
gen DifferentFromTarget=1 if Isyour=="Yes"
replace Different=0 if Isyour=="No"
drop if ID==.
keep ID DifferentF
save SpecialQ.dta, replace

*SPF data
use spf_inflation.dta, clear
egen count=count(pce_forward), by(ID)
egen id=group(ID) if count>=31 & count!=.
tab id
keep if id!=.
gen t=yq(YEAR, QUARTER)
xtset id t
format t %tq

gen deviation=pce_forward-2
gen sqdeviation=(pce_forward-2)^2
gen boundeps02=abs(pce_forward-2)<0.2
gen boundeps05=abs(pce_forward-2)<0.5

*For CPI
gen boundeps02cpi=abs(cpi_forward-2.3)<0.2
gen boundeps05cpi=abs(cpi_forward-2.3)<0.5
gen sqdeviationcpi=(cpi_forward-2.3)^2

*For bivariate
gen box0202=boundeps02cpi==1&boundeps02==1 if cpi_forward!=. & pce_forward!=.
gen box0505=boundeps05cpi==1&boundeps05==1 if cpi_forward!=. & pce_forward!=.

*For 10yr instead of 5yr/5ry forwards
gen sqdeviation10y=(PCE10YR-2)^2
gen boundeps0210y=abs(PCE10YR-2)<0.2
gen boundeps0510y=abs(PCE10YR-2)<0.5

*For 5yr instead of 5yr/5ry forwards
gen sqdeviation5y=(PCE5YR-2)^2
gen boundeps025y=abs(PCE5YR-2)<0.2
gen boundeps055y=abs(PCE5YR-2)<0.5

save boundsanchoringdata.dta, replace
rolling DEV=r(mean), window(9) saving(dev.dta, replace): sum deviation
rolling BOUND02=r(mean), window(9) saving(bound02.dta, replace): sum boundeps02
rolling BOUND05=r(mean), window(9) saving(bound05.dta, replace): sum boundeps05
rolling MSD=r(mean) N=r(N), window(9) saving(sqdev.dta, replace): sum sqdeviation

rolling BOUND02cpi=r(mean), window(9) saving(bound02cpi.dta, replace): sum boundeps02cpi
rolling BOUND05cpi=r(mean), window(9) saving(bound05cpi.dta, replace): sum boundeps05cpi
rolling MSDcpi=r(mean) Ncpi=r(N), window(9) saving(sqdevcpi.dta, replace): sum sqdeviationcpi

rolling BOX0202=r(mean) Nbox=r(N), window(9) saving(box0202.dta, replace): sum box0202
rolling BOX0505=r(mean), window(9) saving(box0505.dta, replace): sum box0505

rolling BOUND0210y=r(mean), window(9) saving(bound0210y.dta, replace): sum boundeps0210y
rolling BOUND0510y=r(mean), window(9) saving(bound0510y.dta, replace): sum boundeps0510y
rolling MSD10y=r(mean) N=r(N), window(9) saving(sqdev10y.dta, replace): sum sqdeviation10y

rolling BOUND025y=r(mean), window(9) saving(bound025y.dta, replace): sum boundeps025y
rolling BOUND055y=r(mean), window(9) saving(bound055y.dta, replace): sum boundeps055y
rolling MSD5y=r(mean) N=r(N), window(9) saving(sqdev5y.dta, replace): sum sqdeviation5y

*Alternative window length for pce bound anchoring

rolling BOUND02w5=r(mean), window(5) saving(bound02w5.dta, replace): sum boundeps02
rolling BOUND05w5=r(mean), window(5) saving(bound05w5.dta, replace): sum boundeps05
rolling MSDw5=r(mean) Nw5=r(N), window(5) saving(sqdevw5.dta, replace): sum sqdeviation


rolling BOUND02w13=r(mean), window(13) saving(bound02w13.dta, replace): sum boundeps02
rolling BOUND05w13=r(mean), window(13) saving(bound05w13.dta, replace): sum boundeps05
rolling MSDw13=r(mean) Nw13=r(N), window(13) saving(sqdevw13.dta, replace): sum sqdeviation

use bound05.dta, clear

foreach stub in sqdev bound02 bound02cpi bound05cpi sqdevcpi box0202 box0505 sqdev10y bound0210y bound0510y sqdev5y bound025y bound055y dev {
	merge 1:1 id start using `stub'.dta
	drop _merge
}

gen t=(start+end)/2
merge 1:1 id t using boundsanchoringdata.dta
drop _merge
save boundsanchoringdata.dta, replace

foreach stub in bound02w5 bound05w5 sqdevw5 bound02w13 bound05w13 sqdevw13 {
	use `stub'.dta, clear
	gen t=(start+end)/2
	save `stub'.dta, replace
}

use boundsanchoringdata.dta, 
foreach stub in bound02w5 bound05w5 sqdevw5 bound02w13 bound05w13 sqdevw13 {
	merge 1:1 id t using `stub'.dta
	drop _merge
}

format t %tq
gen boundanchored02=BOUND02==1 if (BOUND02!=. & N>=6)
gen boundanchored05=BOUND05==1 if (BOUND05!=. & N>=6)
gen RMSD=MSD^(1/2) if N>=6

gen boundanchored02cpi=BOUND02cpi==1 if (BOUND02cpi!=. & Ncpi>=6)
gen boundanchored05cpi=BOUND05==1 if (BOUND05cpi!=. & Ncpi>=6)
gen RMSDcpi=MSDcpi^(1/2) if Ncpi>=6

gen boxanchored0202=BOX0202==1 if (BOX0202!=. & Nbox>=6)
gen boxanchored0505=BOX0505==1 if (BOX0505!=. & Nbox>=6)

gen boundanchored02w5=BOUND02w5==1 if (BOUND02w5!=. & Nw5>=3)
gen boundanchored05w5=BOUND05w5==1 if (BOUND05w5!=. & Nw5>=3)
gen RMSDw5=MSDw5^(1/2) if Nw5>=3

gen boundanchored02w13=BOUND02w13==1 if (BOUND02w13!=. & Nw13>=9)
gen boundanchored05w13=BOUND05w13==1 if (BOUND05w13!=. & Nw13>=9)
gen RMSDw13=MSDw13^(1/2) if Nw13>=9

gen boundanchored0210y=BOUND0210y==1 if (BOUND0210y!=. & N>=6)
gen boundanchored0510y=BOUND0510y==1 if (BOUND0510y!=. & N>=6)
gen RMSD10y=MSD10y^(1/2) if N>=6

gen boundanchored025y=BOUND025y==1 if (BOUND025y!=. & N>=6)
gen boundanchored055y=BOUND055y==1 if (BOUND055y!=. & N>=6)
gen RMSD5y=MSD5y^(1/2) if N>=6

gen belowtarget=DEV<0 if (DEV!=. & N>=6)
gen abovetarget=DEV>0 if (DEV!=. & N>=6)
gen attarget=DEV==0 if (DEV!=. & N>=6)
foreach stub in boundanchored02 boundanchored05 RMSD {
    gen `stub'below=`stub' if belowtarget==1
	gen `stub'above=`stub' if abovetarget==1
	gen `stub'exact=`stub' if attarget==1
}
*Merge with data on special questions from 2012
merge m:1 ID using SpecialQ.dta
drop _merge
**Merge with FRED data
merge m:1 t using freddata.dta
drop _merge
drop if t==.
gen pre_target=YEAR<2012
gen post_target=YEAR>=2012&YEAR<2016
gen post_liftoff=YEAR>=2016&YEAR<2020
gen covid=YEAR>=2020
save boundsanchoringdata.dta, replace

collapse YEAR QUARTER sqdeviation PiPCE UNRATE USREC meanPCE sdPCE FEDFUNDS EPUMONET RMSD* boundanchored* boxanchored* belowtarget abovetarget attarget (p25) p25RMSD=RMSD p25pce_forward=pce_forward p25RMSDcpi=RMSDcpi (p75) p75RMSD=RMSD p75pce_forward=pce_forward p75RMSDcpi=RMSDcpi (p50) p50RMSDcpi=RMSDcpi p50RMSD=RMSD p50pce_forward=pce_forward p50RMSDw5=RMSDw5 p50RMSDw13=RMSDw13 p50RMSD10y=RMSD10y p50RMSD5y=RMSD5y p50RMSDabove=RMSDabove p50RMSDbelow=RMSDbelow, by(t)
tsset t

*Merge with datasets made in the file prepare_data_bounds_anchoring_altsamples.do, which use smaller and larger samples of forecasters.
merge 1:1 t using boundsanchoringdatatimeseries_small.dta
drop _merge
merge 1:1 t using boundsanchoringdatatimeseries_large.dta
drop _merge
**Merge with tips breakeven data
merge 1:1 t using tips.dta
drop _merge
**Merge with UCSVSW data
merge 1:1 t using UCSVSW.dta
drop _merge

gen pre_target=YEAR<2012
gen post_target=YEAR>=2012&YEAR<2016
gen post_liftoff=YEAR>=2016&YEAR<2020
gen covid=YEAR>=2020

save boundsanchoringdatatimeseries.dta, replace

*Delete intermediate data files
foreach stub in long_term_inflation.dta long_term_inflation.xlsx quarterly_inflation.dta quarterly_inflation.xlsx freddata.dta pce.dta bound02.dta bound02cpi.dta bound02w5.dta bound02w13.dta bound05.dta bound05cpi.dta bound05w5.dta bound05w13.dta bound0210y.dta bound0510y.dta bound025y.dta bound055y.dta boundsanchoringdata_largesample.dta boundsanchoringdata_smallsample.dta boundsanchoringdatatimeseries_large.dta boundsanchoringdatatimeseries_small.dta box0202.dta box0505.dta dev.dta SpecialQ.dta sqdev.dta sqdev10y.dta sqdev5y.dta sqdevcpi.dta sqdevw5.dta sqdevw13.dta tips.dta UCSVSW.dta {
    erase `stub'
}

