clear
set more off

**Larger sample (less restrictive)
use spf_inflation.dta, clear
egen count=count(pce_forward), by(ID)
egen id=group(ID) if count>=15 & count!=.
tab id
keep if id!=.
gen t=yq(YEAR, QUARTER)
xtset id t
format t %tq

gen sqdeviation=(pce_forward-2)^2
gen boundeps02=abs(pce_forward-2)<0.2
gen boundeps05=abs(pce_forward-2)<0.5

save boundsanchoringdata_largesample.dta, replace
rolling BOUND02=r(mean), window(9) saving(bound02.dta, replace): sum boundeps02
rolling BOUND05=r(mean), window(9) saving(bound05.dta, replace): sum boundeps05
rolling MSD=r(mean) N=r(N), window(9) saving(sqdev.dta, replace): sum sqdeviation

use bound05.dta, clear

foreach stub in sqdev bound02 {
	merge 1:1 id start using `stub'.dta
	drop _merge
}

gen t=(start+end)/2
merge 1:1 id t using boundsanchoringdata_largesample.dta
drop _merge


format t %tq
gen boundanchored02=BOUND02==1 if (BOUND02!=. & N>=5)
gen boundanchored05=BOUND05==1 if (BOUND05!=. & N>=5)
gen RMSD=MSD^(1/2) if N>=6



*By industry
*INDUSTRY=1 for financial service provider, 2 for nonfinancial service provider, 3 for unknown
foreach stub in boundanchored02 boundanchored05 RMSD pce_forward {
	gen `stub'_fin=`stub' if INDUSTRY==1
	gen `stub'_nonfin=`stub' if INDUSTRY==2
	gen `stub'_unknown=`stub' if INDUSTRY==3
}

save boundsanchoringdata_largesample.dta, replace

collapse boundanchored* (p25) p25RMSD=RMSD p25pce_fin=pce_forward_fin p25pce_nonfin=pce_forward_nonfin (p75) p75RMSD=RMSD p75pce_fin=pce_forward_fin p75pce_nonfin=pce_forward_nonfin (p50) p50RMSD=RMSD p50RMSD_fin=RMSD_fin p50RMSD_nonfin=RMSD_nonfin p50RMSD_unknown=RMSD_unknown p50pce_fin=pce_forward_fin p50pce_nonfin=pce_forward_nonfin (count) Nfin=RMSD_fin Nnonfin=RMSD_nonfin Nunknown=RMSD_unknown, by(t)
tsset t
rename * *large 
rename tlarge t
save boundsanchoringdatatimeseries_large.dta, replace


**Smaller sample (more restrictive)
use spf_inflation.dta, clear
egen count=count(pce_forward), by(ID)
egen id=group(ID) if count>=40 & count!=.
tab id
keep if id!=.
gen t=yq(YEAR, QUARTER)
xtset id t
format t %tq

gen sqdeviation=(pce_forward-2)^2
gen boundeps02=abs(pce_forward-2)<0.2
gen boundeps05=abs(pce_forward-2)<0.5

save boundsanchoringdata_smallsample.dta, replace
rolling BOUND02=r(mean), window(9) saving(bound02.dta, replace): sum boundeps02
rolling BOUND05=r(mean), window(9) saving(bound05.dta, replace): sum boundeps05
rolling MSD=r(mean) N=r(N), window(9) saving(sqdev.dta, replace): sum sqdeviation

use bound05.dta, clear

foreach stub in sqdev bound02 {
	merge 1:1 id start using `stub'.dta
	drop _merge
}

gen t=(start+end)/2
merge 1:1 id t using boundsanchoringdata_smallsample.dta
drop _merge


format t %tq
gen boundanchored02=BOUND02==1 if (BOUND02!=. & N>=6)
gen boundanchored05=BOUND05==1 if (BOUND05!=. & N>=6)
gen RMSD=MSD^(1/2) if N>=6
save boundsanchoringdata_smallsample.dta, replace

collapse boundanchored* (p25) p25RMSD=RMSD (p75) p75RMSD=RMSD (p50) p50RMSD=RMSD, by(t)
tsset t
rename * *small 
rename tsmall t
save boundsanchoringdatatimeseries_small.dta, replace